@@ -1,18 +1,20 @@
+use strict;
+use warnings;
+
 package Data::Couplet;
-our $VERSION = '0.0101';
+our $VERSION = '0.02003813';
 
 
 # ABSTRACT: Yet another (But Hopefully Better) Key-Value Storage mechanism
 
 # $Id:$
-use strict;
-use warnings;
 use Moose;
 use Data::Couplet::Private ();
 use Carp;
 use namespace::autoclean;
 
 extends 'Data::Couplet::Private';
+with('MooseX::Clone');
 
 
 
@@ -20,15 +22,15 @@ extends 'Data::Couplet::Private';
 
 
 sub BUILDARGS {
-  my $class = shift;
-
-  if ( scalar @_ & 1 ) {
-    Carp::croak("Uneven list sent. ERROR: Must be an ordered array that simulates a hash [k,v,k,v]");
+  my @args  = @_;
+  my $class = shift @args;
+  if ( scalar @args & 1 ) {
+    Carp::croak('Uneven list sent. ERROR: Must be an ordered array that simulates a hash [k,v,k,v]');
   }
 
   my $c = Data::Couplet::Private->new();
-  while (@_) {
-    $c->_set( shift, shift );
+  while (@args) {
+    $c->_set( shift @args, shift @args );
   }
   return { %{$c} };
 }
@@ -55,7 +57,7 @@ sub unset_at {
 }
 
 
-sub unset_key($) {
+sub unset_key {
   my ( $self, $key ) = @_;
   unless ( exists $self->{_kv}->{$key} ) {
     return $self;
@@ -63,7 +65,7 @@ sub unset_key($) {
   my $index = $self->{_ki}->{$key};
   $self->_unset_at($index);
   $self->_unset_key($key);
-  $self->_move_key_range( $index, $#{ $self->{_ik} }, -1 );
+  $self->_move_key_range( $index, $#{ $self->{_ik} }, 0 - 1 );
   return $self;
 }
 
@@ -90,19 +92,19 @@ sub values {
 
 
 sub values_ref {
-  my ($self) = @_;
-  return [ $self->values(@_) ];
+  my ( $self, @args ) = @_;
+  return [ $self->values(@args) ];
 }
 
 
 sub key_values {
-  my ( $self ) = @_;
-  return map { $self->{_ko}->{$_}, $self->{_kv}->{$_} } @{ $self->{_ik} };
+  my ($self) = @_;
+  return map { ( $self->{_ko}->{$_}, $self->{_kv}->{$_} ) } @{ $self->{_ik} };
 }
 
 
 sub key_values_paired {
-  my ( $self ) = @_;
+  my ($self) = @_;
   return map { [ $self->{_ko}->{$_}, $self->{_kv}->{$_} ] } @{ $self->{_ik} };
 }
 
@@ -149,7 +151,7 @@ sub swap {
   my ( $self, $key_left, $key_right ) = @_;
   return $self;
 }
-
+no Moose;
 __PACKAGE__->meta->make_immutable();
 1;
 
@@ -164,7 +166,7 @@ Data::Couplet - Yet another (But Hopefully Better) Key-Value Storage mechanism
 
 =head1 VERSION
 
-version 0.0101
+version 0.02003813
 
 =head1 ALPHA CODE
 
@@ -182,14 +184,14 @@ Why is this module different?
 
 =item 1. No Tied Hashes.
 
-Tied hashes are IMO Ugly. OO Objects are far more handy for many things. Especially
+Tied hashes are IMO Ugly. Objects are far more handy for many things. Especially
 in moose world. You want tied hashes, do it yourself.
 
 =item 2. Trying Hard to preserve non-scalar keys.
 
 I want it to be possible, to retain arbitrary references used as keys.
 
-=item 3. Permutative.
+=item 3. Permutation.
 
 Its not here yet, but there I<Will> eventually be reordering functions.
 
@@ -198,8 +200,8 @@ Its not here yet, but there I<Will> eventually be reordering functions.
 I seriously looked all over CPAN for something that suited my needs and didn't find any.
 
 I then tried with Tie::IxHash::ButMoreFun, and then discovered that how I was
-using Tie::IxHash wasn't even sustainable on different versions of perl, and
-basedd on the 1997 release date, I gave up on seeing that fixed.
+using Tie::IxHash wasn't even sustainable on different versions of Perl, and
+based on the 1997 release date, I gave up on seeing that fixed.
 
 
 
@@ -239,7 +241,7 @@ Create a new Data::Couplet entity using a series of ordered pairs.
 
 =head3 ->set( Any $object, Any  $value ) : $self : Modifier
 
-Record the association of a key ( any object that can be stringified )  to a value.
+Record the association of a key ( any object that can be coerced into a string )  to a value.
 
 New entries are pushed on the logical right hand end of it in array context.
 
@@ -283,8 +285,8 @@ Should be identical to the above code.
 =head3 ->unset_key( Str $key ) : $self : Modifier
 
 This is what ->unset ultimately calls, except ->unset does implicit
-object_to_key conversion first. At present, thats not anything huge, its just
-C<$object> to stringify it. But this may change at some future time. So use that
+object_to_key conversion first. At present, that's not anything huge, its just
+C<$object> to convert it to a string. But this may change at some future time. So use that
 method instead.
 
 
@@ -302,7 +304,7 @@ of what object keys are.
 
 =head3 ->value_at( Int $index ) : Any $value
 
-Like value, but you need to know where in the dataset the item is.
+Like value, but you need to know where in the data set the item is.
 
 
 
